#!/bin/bash

# The software in this package is distributed under the GNU General
# Public License version 2 (with a special exception described below).
#
# A copy of GNU General Public License (GPL) is included in this distribution,
# in the file COPYING.GPL.
#
# As a special exception, if other files instantiate templates or use macros
# or inline functions from this file, or you compile this file and link it
# with other works to produce a work based on this file, this file
# does not by itself cause the resulting work to be covered
# by the GNU General Public License.
#
# However the source code for this file must still be made available
# in accordance with section (3) of the GNU General Public License.
#
# This exception does not invalidate any other reasons why a work based
# on this file might be covered by the GNU General Public License.

# check.sh
# check a python file using pylint and pep8

# debug mode:
#set -x

if [ $# != 1 ]; then
    echo "Unexpected number of args, just want a single python file"
    exit 1
fi

# look for test in guest tests
test_file=
if [ -f "$1" ]; then
    test_file="$1"
fi

# look for test in guest tests
if [ -f "$1.py" ]; then
    test_file="$1.py"
fi

# error if not found yet
if [ "$test_file" = "" ]; then
    echo "Could not find $1!"
    exit 2
fi

# run pylint
echo "pylint:"
pylint --reports=no $test_file
pylint_return=$?
echo

# run pep8
echo "pep8:"
pep8 "$test_file"
pep8_return=$?
echo

# done
echo Done checking
if [[ $pylint_return == 0 && $pep8_return == 0 ]]; then
    echo "Everything seems to be fine"
else
    echo "Please correct"
fi
